@@ -29,7 +29,14 @@ DESC
     [ INVALID, 'code-only' => 'status line stops after code, no phrase'],
     [ INVALID, 'http-lower' => 'http/1.1 instead of HTTP/1.1'],
     [ INVALID, 'proto:HTTP/0.9' => 'HTTP/0.9 instead of HTTP/1.1'],
+    [ INVALID, 'proto:HTTP/1.10' => 'HTTP/1.10 instead of HTTP/1.1'],
+    [ INVALID, 'proto:HTTP/1.00' => 'HTTP/1.00 instead of HTTP/1.0'],
+    [ INVALID, 'proto:HTTP/1.01' => 'HTTP/1.01 instead of HTTP/1.0'],
     [ INVALID, 'proto:HTTP/1.2' => 'HTTP/1.2 instead of HTTP/1.1'],
+    [ INVALID, 'proto:HTTP/1.1 ' => 'HTTP/1.1+SPACE instead of HTTP/1.1'],
+    [ INVALID, "proto:HTTP/1.1\t" => 'HTTP/1.1+TAB instead of HTTP/1.1'],
+    #[ INVALID, "proto:HTTP/1.1\r" => 'HTTP/1.1+CR instead of HTTP/1.1'],
+    [ INVALID, "proto: HTTP/1.1" => 'SPACE+HTTP/1.1 instead of HTTP/1.1'],
     [ INVALID, 'proto:FTP/1.1' => 'FTP/1.1 instead of HTTP/1.1'],
     [ INVALID, 'cr-no-lf' => 'use \r instead of \r\n' ],
     [ INVALID, 'no-cr-lf' => 'use \n instead of \r\n' ],
@@ -109,7 +116,7 @@ sub make_response {
     }
     if (!$only) {
 	$hdr .= "Yet-another-header: foo\r\n";
-	$hdr .= "Content-length :".length($data)."\r\n" if $te eq 'clen';
+	$hdr .= "Content-length: ".length($data)."\r\n" if $te eq 'clen';
     }
     $statusline ||= "HTTP/$version $code ok\r\n";
     $hdr = "$statusline$hdr\r\n";
